@@ -1,20 +1,9 @@
-/***************************************************************************
-                          filters.cxx  -  description
-                             -------------------
-    begin                : Fri Jun 30 2000
-    copyright            : (C) 2000 by Hans Dijkema
-    email                : kmailcvt@hum.org
- ***************************************************************************/
+/*
+  SPDX-FileCopyrightText: 2000 Hans Dijkema <kmailcvt@hum.org>
+  SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
 
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
-/* Copyright (c) 2012-2020 Laurent Montel <montel@kde.org>                      */
+  SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 // Local Includes
 #include "filters.h"
@@ -38,8 +27,6 @@ public:
         : name(_name)
         , author(_author)
         , info(_info)
-        , filterImporter(nullptr)
-        , filterInfo(nullptr)
     {
     }
 
@@ -147,7 +134,7 @@ void Filter::setInfo(const QString &_info)
     d->info = _info;
 }
 
-bool Filter::importMessage(const QString &folderName, const QString &msgPath, bool duplicateCheck, MailImporter::MessageStatus status)
+bool Filter::importMessage(const QString &folderName, const QString &msgPath, bool duplicateCheck, const MailImporter::MessageStatus &status)
 {
     return filterImporter()->importMessage(folderName, msgPath, duplicateCheck, status);
 }
