@@ -1,19 +1,7 @@
 /*
-  Copyright (c) 2012-2019 Montel Laurent <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "filterbalsa.h"
@@ -26,12 +14,6 @@ using namespace MailImporter;
 class MailImporter::FilterBalsaPrivate
 {
 public:
-    FilterBalsaPrivate()
-        : mImportDirDone(0)
-        , mTotalDir(0)
-    {
-    }
-
     int mImportDirDone = 0;
     int mTotalDir = 0;
 };
@@ -95,7 +77,7 @@ void FilterBalsa::processDirectory(const QString &path)
         if (filterInfo()->shouldTerminate()) {
             break;
         }
-        if (!(*filename == QLatin1String(".") || *filename == QLatin1String(".."))) {
+        if (!(*filename == QLatin1Char('.') || *filename == QLatin1String(".."))) {
             filterInfo()->setCurrent(0);
             importDirContents(dir.filePath(*filename));
             filterInfo()->setOverall((d->mTotalDir > 0) ? (int)((float)d->mImportDirDone / d->mTotalDir * 100) : 0);
@@ -184,18 +166,22 @@ void FilterBalsa::importFiles(const QString &dirName)
             if (!generatedPath) {
                 _path = i18nc("define folder name where we import evolution mails", "Evolution-Import");
                 QString _tmp = dir.filePath(*mailFile);
-                _tmp = _tmp.remove(mailDir(), Qt::CaseSensitive);
+                _tmp.remove(mailDir(), Qt::CaseSensitive);
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
                 QStringList subFList = _tmp.split(QLatin1Char('/'), QString::SkipEmptyParts);
+#else
+                QStringList subFList = _tmp.split(QLatin1Char('/'), Qt::SkipEmptyParts);
+#endif
                 QStringList::ConstIterator end(subFList.end());
                 for (QStringList::ConstIterator it = subFList.constBegin(); it != end; ++it) {
                     QString _cat = *it;
                     if (!(_cat == *mailFile)) {
                         if (_cat.startsWith(QLatin1Char('.'))) {
-                            _cat = _cat.remove(0, 1);
+                            _cat.remove(0, 1);
                         }
                         //Evolution store inbox as "."
                         if (_cat.startsWith(QLatin1Char('.'))) {
-                            _cat = _cat.replace(0, 1, QStringLiteral("Inbox/"));
+                            _cat.replace(0, 1, QStringLiteral("Inbox/"));
                         }
 
                         _path += QLatin1Char('/') + _cat;
@@ -224,7 +210,7 @@ void FilterBalsa::importFiles(const QString &dirName)
 MailImporter::MessageStatus FilterBalsa::statusFromFile(const QString &filename)
 {
     MailImporter::MessageStatus status;
-    const int statusIndex = filename.indexOf(QStringLiteral(":2,"));
+    const int statusIndex = filename.indexOf(QLatin1String(":2,"));
     if (statusIndex != -1) {
         const QString statusStr = filename.right(filename.length() - statusIndex - 3);
         if (statusStr.contains(QLatin1Char('S'))) {
