@@ -1,24 +1,15 @@
-/***************************************************************************
-            filter_thebat.h  -  TheBat! mail import
-                             -------------------
-    begin                : April 07 2005
-   copyright            : (C) 2005 by Danny Kukawka
-   email                : danny.kukawka@web.de
-***************************************************************************/
+/*
+  filterthebat.cpp  -  TheBat! mail import
 
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
-/* Copyright (c) 2012-2020 Laurent Montel <montel@kde.org>                      */
+  SPDX-FileCopyrightText: 2005 Danny Kukawka <danny.kukawka@web.de>
+  SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
+
+  SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "filterthebat.h"
 
-#include <QRegExp>
+#include <QRegularExpression>
 #include <KLocalizedString>
 #include <QFileDialog>
 #include <QTemporaryFile>
@@ -28,10 +19,6 @@ using namespace MailImporter;
 class MailImporter::FilterTheBatPrivate
 {
 public:
-    FilterTheBatPrivate()
-    {
-    }
-
     int mImportDirDone = 0;
     int mTotalDir = 0;
 };
@@ -166,7 +153,7 @@ void FilterTheBat::importFiles(const QString &FileName)
 
     long l = 0;
     QByteArray input(50, '\0');
-    QRegExp regexp(QStringLiteral("!.p.0"));
+    const QRegularExpression regexp(QStringLiteral("!.p.0"));
     QFile tbb(FileName);
     int iFound = 0;
     int count = 0;
@@ -241,7 +228,9 @@ void FilterTheBat::importFiles(const QString &FileName)
                 tmp.write(input.constData(), endPos - lastPos);
                 tmp.flush();
 
-                importMessage(_path, tmp.fileName(), filterInfo()->removeDupMessage());
+                if (!importMessage(_path, tmp.fileName(), filterInfo()->removeDupMessage())) {
+                    filterInfo()->addErrorLogEntry(i18n("Could not import %1", tmp.fileName()));
+                }
 
                 lastPos = endPos + 48;
                 tbb.seek(lastPos);
